==> ascord-0.0.4.tar.gz: ascord-0.0.4/README.md <==
<img src='https://img.shields.io/badge/Python-FFD43B?style=for-the-badge&logo=python&logoColor=darkgreen'>
<img src='https://img.shields.io/badge/Windows-0078D6?style=for-the-badge&logo=windows&logoColor=white'>
<img src='https://img.shields.io/badge/Linux-FCC624?style=for-the-badge&logo=linux&logoColor=black'>


<img src='https://img.shields.io/badge/Visual_Studio_Code-0078D4?style=for-the-badge&logo=visual%20studio%20code&logoColor=white'>




# AsCord 0.0.2

![AsCord](https://img.shields.io/badge/AsCord-0.0.2-green)


---

# Update log

**Update 0.0.4**: Fixed the cogs generation.

**Update 0.0.3**: Fixed a bug.

**Update 0.0.2**: Fixed the `__init__.py` file.

**Update 0.0.1**: Initial release of AsCord.

---

# Info: 

* This package makes it easy for python developers to generate `discord.py` bots. 
* With not more than `3 lines of code`, you will be able to generate fully functional discord bots. 
* You are also provided with an option of either generating discord bots WITH cogs or WITHOUT cogs.

# Installation

Type the following command to install the package

```python
pip install ascord
```
* or

```python
pip3 install ascord
```
# Usage

* Importing the module

```python
 import ascord
 ```

* Generate a bot without cogs

```python 
astro_cord.as_cord("BOT_NAME", "BOT_PREFIX", "BOT_TOKEN")
```

* Generate a bot with cogs

```python
astro_cord.as_cogs("BOT_NAME", "BOT_PREFIX", "BOT_TOKEN")
```

--> After the script is generated, you can run the bot.


# Credits

**Developed by: Kavin Jindal**

==> ascord-0.0.6.tar.gz: ascord-0.0.6/README.md <==
<img src='https://img.shields.io/badge/Python-FFD43B?style=for-the-badge&logo=python&logoColor=darkgreen'>
<img src='https://img.shields.io/badge/Windows-0078D6?style=for-the-badge&logo=windows&logoColor=white'>
<img src='https://img.shields.io/badge/Linux-FCC624?style=for-the-badge&logo=linux&logoColor=black'>


<img src='https://img.shields.io/badge/Visual_Studio_Code-0078D4?style=for-the-badge&logo=visual%20studio%20code&logoColor=white'>




# AsCord 0.0.6

![AsCord](https://img.shields.io/badge/AsCord-0.0.2-green)


---

# Update log

**Update 0.0.4**: Fixed the cogs generation.

**Update 0.0.3**: Fixed a bug.

**Update 0.0.2**: Fixed the `__init__.py` file.

**Update 0.0.1**: Initial release of AsCord.

---

# Info: 

* This package makes it easy for python developers to generate `discord.py` bots. 
* With not more than `3 lines of code`, you will be able to generate fully functional discord bots. 
* You are also provided with an option of either generating discord bots WITH cogs or WITHOUT cogs.

# Installation

Type the following command to install the package

```python
pip install ascord
```
* or

```python
pip3 install ascord
```
# Usage

* Importing the module

```python
 import ascord
 ```

* Generate a bot without cogs

```python 
ascord.as_cord("BOT_NAME", "BOT_PREFIX", "BOT_TOKEN")
```

* Generate a bot with cogs

```python
ascord.as_cogs("BOT_NAME", "BOT_PREFIX", "BOT_TOKEN")
```

--> After the script is generated, you can run the bot.


# Credits

**Developed by: Kavin Jindal**
